SET SQL DIALECT 3;
SET NAMES utf8;
CREATE DATABASE '../weo.fdb' USER 'SYSDBA' PASSWORD 'masterkey' PAGE_SIZE 16384 DEFAULT CHARACTER SET utf8;
CONNECT '../weo.fdb' USER 'SYSDBA' PASSWORD 'masterkey';
SET SQL DIALECT 3;
SET NAMES utf8;
CREATE TABLE bon_livraison(
  bon_livraison_id INTEGER    ,
  bon_livraison_facturable VARCHAR(1)  NOT NULL  ,
  bon_livraison_affaire INTEGER  NOT NULL  ,
  bon_livraison_numero INTEGER    ,
  bon_livraison_date_creation DATE  NOT NULL  ,
  bon_livraison_commande INTEGER  NOT NULL  ,
  bon_livraison_client INTEGER  NOT NULL  ,
  bon_livraison_adresse VARCHAR(255)  NOT NULL  ,
  bon_livraison_description VARCHAR(255)  NOT NULL  ,
  bon_livraison_facture INTEGER  NOT NULL  ,
  bon_livraison_tva INTEGER  NOT NULL    ,
  PRIMARY KEY(bon_livraison_id));


CREATE GENERATOR bon_livraison_bon_livraison_num;

SET TERM !; 
CREATE TRIGGER AINC_bon_livraison FOR bon_livraison BEFORE INSERT  
AS
BEGIN 
  IF (NEW.bon_livraison_numero IS NULL) THEN 
    NEW.bon_livraison_numero = GEN_ID(bon_livraison_bon_livraison_num, 1); 
END! 
SET TERM ;! 

CREATE TABLE affaire(
  affaire_id INTEGER    ,
  affaire_numero INTEGER    ,
  affaire_tier INTEGER  NOT NULL  ,
  affaire_nom VARCHAR(50)  NOT NULL  ,
  affaire_date_creation DATE  NOT NULL  ,
  affaire_date_fin DATE  NOT NULL  ,
  affaire_date_maj DATE  NOT NULL  ,
  affaire_solde VARCHAR(1)  NOT NULL  ,
  affaire_total_achat_en_cours DECIMAL(18,2)  NOT NULL  ,
  affaire_total_achat_rec DECIMAL(18,2)  NOT NULL  ,
  affaire_total_achat DECIMAL(18,2)  NOT NULL  ,
  affaire_total_vente_en_cours DECIMAL(18,2)  NOT NULL  ,
  affaire_total_vente_exp DECIMAL(18,2)  NOT NULL  ,
  affaire_total_vente DECIMAL(18,2)  NOT NULL  ,
  affaire_adresse_liv VARCHAR(255)  NOT NULL  ,
  affaire_description VARCHAR(255)  NOT NULL    ,
  PRIMARY KEY(affaire_id));


CREATE GENERATOR affaire_affaire_numero;

SET TERM !; 
CREATE TRIGGER AINC_affaire FOR affaire BEFORE INSERT  
AS
BEGIN 
  IF (NEW.affaire_numero IS NULL) THEN 
    NEW.affaire_numero = GEN_ID(affaire_affaire_numero, 1); 
END! 
SET TERM ;! 

CREATE TABLE tiers(
  tier_id INTEGER    ,
  tier_compte VARCHAR(20)  NOT NULL  ,
  tier_compte_fr VARCHAR(20)  NOT NULL  ,
  tier_nom VARCHAR(50)  NOT NULL  ,
  tier_date_creation DATE  NOT NULL  ,
  tiers_adresse VARCHAR(255)  NOT NULL  ,
  tier_type VARCHAR(1)  NOT NULL  ,
  tier_echeance_reglement INTEGER  NOT NULL  ,
  tier_famille INTEGER  NOT NULL  ,
  tier_default_tva INTEGER  NOT NULL  ,
  tier_telephone VARCHAR(20)  NOT NULL  ,
  tier_fax VARCHAR(20)  NOT NULL  ,
  tier_contact VARCHAR(50)  NOT NULL  ,
  tier_email_contact VARCHAR(50)  NOT NULL  ,
  tier_site_web VARCHAR(50)  NOT NULL  ,
  tier_represent INTEGER  NOT NULL    ,
  PRIMARY KEY(tier_id));


CREATE GENERATOR tiers_tier_id;

SET TERM !; 
CREATE TRIGGER AINC_tiers FOR tiers BEFORE INSERT  
AS
BEGIN 
  IF (NEW.tier_id IS NULL) THEN 
    NEW.tier_id = GEN_ID(tiers_tier_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE familles(
  famille_id INTEGER    ,
  famille_nom VARCHAR(50)  NOT NULL  ,
  famille_description VARCHAR(255)  NOT NULL  ,
  famille_type VARCHAR(1)  NOT NULL    ,
  PRIMARY KEY(famille_id));


CREATE GENERATOR familles_famille_id;

SET TERM !; 
CREATE TRIGGER AINC_familles FOR familles BEFORE INSERT  
AS
BEGIN 
  IF (NEW.famille_id IS NULL) THEN 
    NEW.famille_id = GEN_ID(familles_famille_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE tva(
  tva_id INTEGER    ,
  tva_nom VARCHAR(20)  NOT NULL  ,
  tva_taux DECIMAL(3,2)  NOT NULL  ,
  tva_description VARCHAR(30)  NOT NULL  ,
  tva_compte_compta_vente VARCHAR(10)  NOT NULL  ,
  tva_compte_compta_achat VARCHAR(10)  NOT NULL    ,
  PRIMARY KEY(tva_id));


CREATE GENERATOR tva_tva_id;

SET TERM !; 
CREATE TRIGGER AINC_tva FOR tva BEFORE INSERT  
AS
BEGIN 
  IF (NEW.tva_id IS NULL) THEN 
    NEW.tva_id = GEN_ID(tva_tva_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE represent(
  represent_id INTEGER    ,
  represent_nom VARCHAR(30)  NOT NULL  ,
  represent_prenom VARCHAR(30)  NOT NULL  ,
  represent_adresse VARCHAR(255)  NOT NULL  ,
  represent_date_naissance DATE  NOT NULL  ,
  represent_sexe VARCHAR(1)  NOT NULL  ,
  represent_date_entree DATE  NOT NULL  ,
  represent_date_sortie DATE  NOT NULL  ,
  represent_tx_com DECIMAL(5,5)  NOT NULL  ,
  represent_photo VARCHAR(100)  NOT NULL    ,
  PRIMARY KEY(represent_id));


CREATE GENERATOR represent_represent_id;

SET TERM !; 
CREATE TRIGGER AINC_represent FOR represent BEFORE INSERT  
AS
BEGIN 
  IF (NEW.represent_id IS NULL) THEN 
    NEW.represent_id = GEN_ID(represent_represent_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE cmd_client(
  cmd_vente_id INTEGER    ,
  cmd_vente_facturable VARCHAR(1)    ,
  cmd_vente_numero INTEGER    ,
  cmd_vente_affaire INTEGER  NOT NULL  ,
  cmd_vente_date_creation DATE  NOT NULL  ,
  cmd_vente_tier INTEGER  NOT NULL  ,
  cmd_vente_tva INTEGER  NOT NULL  ,
  cmd_vente_adresse_liv VARCHAR(255)  NOT NULL  ,
  cmd_vente_description VARCHAR(255)  NOT NULL  ,
  cmd_vente_solde VARCHAR(1)  NOT NULL  ,
  cmd_vente_tva_total DECIMAL(18,2)  NOT NULL  ,
  cmd_vente_ttc DECIMAL(18,2)  NOT NULL    ,
  PRIMARY KEY(cmd_vente_id));


CREATE GENERATOR cmd_client_cmd_vente_numero;

SET TERM !; 
CREATE TRIGGER AINC_cmd_client FOR cmd_client BEFORE INSERT  
AS
BEGIN 
  IF (NEW.cmd_vente_numero IS NULL) THEN 
    NEW.cmd_vente_numero = GEN_ID(cmd_client_cmd_vente_numero, 1); 
END! 
SET TERM ;! 

CREATE TABLE facture(
  facture_id INTEGER    ,
  facture_numero INTEGER  NOT NULL  ,
  facture_client INTEGER  NOT NULL  ,
  facture_date_creation DATE  NOT NULL  ,
  facture_ht DECIMAL(18,2)  NOT NULL  ,
  facture_relation_tva INTEGER  NOT NULL  ,
  facture_tva DECIMAL(18,2)  NOT NULL  ,
  facture_ttc DECIMAL(18,2)  NOT NULL  ,
  facture_echeance DATE  NOT NULL  ,
  facture_type VARCHAR(1)  NOT NULL  ,
  facture_type_bon VARCHAR(1)  NOT NULL  ,
  facture_reglee VARCHAR(1)  NOT NULL  ,
  facture_commentaire VARCHAR(25)  NOT NULL  ,
  facture_representant INTEGER  NOT NULL  ,
  facture_taux_comm DECIMAL(18,5)  NOT NULL    ,
  PRIMARY KEY(facture_id));


CREATE GENERATOR facture_facture_id;

SET TERM !; 
CREATE TRIGGER AINC_facture FOR facture BEFORE INSERT  
AS
BEGIN 
  IF (NEW.facture_id IS NULL) THEN 
    NEW.facture_id = GEN_ID(facture_facture_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE cmd_achat(
  cmd_achat_id INTEGER    ,
  cmd_achat_numero INTEGER    ,
  cmd_achat_affaire INTEGER  NOT NULL  ,
  cmd_achat_date_creation DATE  NOT NULL  ,
  cmd_achat_tier INTEGER  NOT NULL  ,
  cmd_achat_tva INTEGER  NOT NULL  ,
  cmd_achat_adresse_liv VARCHAR(255)  NOT NULL  ,
  cmd_achat_description VARCHAR(255)  NOT NULL  ,
  cmd_achat_solde VARCHAR(1)  NOT NULL  ,
  cmd_achat_tva_total DECIMAL(18,2)  NOT NULL  ,
  cmd_achat_ttc DECIMAL(18,2)  NOT NULL    ,
  PRIMARY KEY(cmd_achat_id));


CREATE GENERATOR cmd_achat_cmd_achat_numero;

SET TERM !; 
CREATE TRIGGER AINC_cmd_achat FOR cmd_achat BEFORE INSERT  
AS
BEGIN 
  IF (NEW.cmd_achat_numero IS NULL) THEN 
    NEW.cmd_achat_numero = GEN_ID(cmd_achat_cmd_achat_numero, 1); 
END! 
SET TERM ;! 

CREATE TABLE cmd_achat_lignes(
  cmd_achat_ligne_id INTEGER    ,
  cmd_achat_ligne_commande INTEGER  NOT NULL  ,
  cmd_achat_ligne_ligne INTEGER    ,
  cmd_achat_ligne_produit INTEGER  NOT NULL  ,
  cmd_achat_achat_ligne_descripti VARCHAR(255)  NOT NULL  ,
  cmd_achat_ligne_delai DATE  NOT NULL  ,
  cmd_achat_ligne_qt_cmd DECIMAL(18,2)  NOT NULL  ,
  cmd_achat_ligne_qt_livrai DECIMAL(18,2)  NOT NULL  ,
  cmd_achat_ligne_pu DECIMAL(18,5)  NOT NULL  ,
  cmd_achat_ligne_solde VARCHAR(1)  NOT NULL    ,
  PRIMARY KEY(cmd_achat_ligne_id));


CREATE GENERATOR cmd_achat_lignes_cmd_achat_lign;

SET TERM !; 
CREATE TRIGGER AINC_cmd_achat_lignes FOR cmd_achat_lignes BEFORE INSERT  
AS
BEGIN 
  IF (NEW.cmd_achat_ligne_id IS NULL) THEN 
    NEW.cmd_achat_ligne_id = GEN_ID(cmd_achat_lignes_cmd_achat_lign, 1); 
END! 
SET TERM ;! 

CREATE TABLE produits(
  produit_id INTEGER    ,
  produit_code VARCHAR(50)  NOT NULL  ,
  produit_libelle VARCHAR(50)  NOT NULL  ,
  produit_description VARCHAR(255)  NOT NULL  ,
  produit_type VARCHAR(1)  NOT NULL  ,
  produit_famille INTEGER  NOT NULL  ,
  produit_date_creat DATE  NOT NULL  ,
  produit_compte_compta VARCHAR(10)  NOT NULL  ,
  produit_compte_compta_fr VARCHAR(10)  NOT NULL  ,
  produit_gest_stock VARCHAR(1)  NOT NULL  ,
  produit_autorise_stock_negatif VARCHAR(1)  NOT NULL  ,
  produit_gest_reapro VARCHAR(1)  NOT NULL  ,
  produit_default_fournisseur INTEGER  NOT NULL  ,
  produit_prix_achat DECIMAL(18,5)  NOT NULL  ,
  produit_default_client INTEGER  NOT NULL  ,
  produit_prix_vente DECIMAL(18,5)  NOT NULL  ,
  produit_cmdachat_min DECIMAL(3,1)  NOT NULL  ,
  produit_cmdachat_max DECIMAL(3,1)  NOT NULL  ,
  produit_cmdvente_min DECIMAL(3,1)  NOT NULL  ,
  produit_cmdvente_max DECIMAL(3,1)  NOT NULL  ,
  produit_stock_min DECIMAL(18,1)  NOT NULL  ,
  produit_stock_max DECIMAL(18,1)  NOT NULL  ,
  produit_stock DECIMAL(18,5)  NOT NULL  ,
  produit_delai_reapro INTEGER  NOT NULL  ,
  produit_image VARCHAR(100)  NOT NULL    ,
  PRIMARY KEY(produit_id));


CREATE GENERATOR produits_produit_id;

SET TERM !; 
CREATE TRIGGER AINC_produits FOR produits BEFORE INSERT  
AS
BEGIN 
  IF (NEW.produit_id IS NULL) THEN 
    NEW.produit_id = GEN_ID(produits_produit_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE cmd_vente_lignes(
  cmd_vente_ligne_id INTEGER    ,
  cmd_vente_ligne_commande INTEGER  NOT NULL  ,
  cmd_vente_ligne_ligne INTEGER    ,
  cmd_vente_ligne_produit INTEGER  NOT NULL  ,
  cmd_vente_ligne_description VARCHAR(255)  NOT NULL  ,
  cmd_vente_ligne_delai DATE  NOT NULL  ,
  cmd_vente_ligne_qt_cmd DECIMAL(18,2)  NOT NULL  ,
  cmd_vente_ligne_qt_livrai DECIMAL(18,2)  NOT NULL  ,
  cmd_vente_ligne_pu_achat DECIMAL(18,5)  NOT NULL  ,
  cmd_vente_ligne_pu DECIMAL(18,5)  NOT NULL  ,
  cmd_vente_ligne_solde VARCHAR(1)  NOT NULL    ,
  PRIMARY KEY(cmd_vente_ligne_id));


CREATE GENERATOR cmd_vente_lignes_cmd_vente_lign;

SET TERM !; 
CREATE TRIGGER AINC_cmd_vente_lignes FOR cmd_vente_lignes BEFORE INSERT  
AS
BEGIN 
  IF (NEW.cmd_vente_ligne_id IS NULL) THEN 
    NEW.cmd_vente_ligne_id = GEN_ID(cmd_vente_lignes_cmd_vente_lign, 1); 
END! 
SET TERM ;! 

CREATE TABLE devis_client(
  devis_id INTEGER    ,
  devis_numero INTEGER    ,
  devis_date_creation DATE  NOT NULL  ,
  devis_tier INTEGER  NOT NULL  ,
  devis_tva INTEGER  NOT NULL  ,
  devis_adresse_liv VARCHAR(255)  NOT NULL  ,
  devis_description VARCHAR(255)  NOT NULL  ,
  devis_solde VARCHAR(1)  NOT NULL  ,
  devis_affaire INTEGER  NOT NULL  ,
  devis_tva_total DECIMAL(18,2)  NOT NULL  ,
  devis_ttc DECIMAL(18,2)  NOT NULL    ,
  PRIMARY KEY(devis_id));


CREATE GENERATOR devis_client_devis_numero;

SET TERM !; 
CREATE TRIGGER AINC_devis_client FOR devis_client BEFORE INSERT  
AS
BEGIN 
  IF (NEW.devis_numero IS NULL) THEN 
    NEW.devis_numero = GEN_ID(devis_client_devis_numero, 1); 
END! 
SET TERM ;! 

CREATE TABLE devis_lignes(
  devis_ligne_id INTEGER    ,
  devis_ligne_devis INTEGER  NOT NULL  ,
  devis_ligne_ligne INTEGER    ,
  devis_ligne_produit INTEGER  NOT NULL  ,
  devis_ligne_description VARCHAR(255)  NOT NULL  ,
  devis_ligne_delai DATE  NOT NULL  ,
  devis_ligne_qt_cmd DECIMAL(18,2)  NOT NULL  ,
  devis_ligne_pu DECIMAL(18,5)  NOT NULL    ,
  PRIMARY KEY(devis_ligne_id));


CREATE GENERATOR devis_lignes_devis_ligne_id;

SET TERM !; 
CREATE TRIGGER AINC_devis_lignes FOR devis_lignes BEFORE INSERT  
AS
BEGIN 
  IF (NEW.devis_ligne_id IS NULL) THEN 
    NEW.devis_ligne_id = GEN_ID(devis_lignes_devis_ligne_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE demande_achat(
  demande_achat_id INTEGER    ,
  demande_achat_numero INTEGER    ,
  demande_achat_date_creation DATE  NOT NULL  ,
  demande_achat_tier INTEGER  NOT NULL  ,
  demande_achat_tva INTEGER  NOT NULL  ,
  demande_achat_adresse_liv VARCHAR(255)  NOT NULL  ,
  demande_achat_description VARCHAR(255)  NOT NULL  ,
  demande_achat_solde VARCHAR(1)  NOT NULL  ,
  demande_achat_affaire INTEGER  NOT NULL  ,
  demande_achat_tva_total DECIMAL(18,2)  NOT NULL  ,
  demande_achat_ttc DECIMAL(18,2)  NOT NULL    ,
  PRIMARY KEY(demande_achat_id));


CREATE GENERATOR demande_achat_demande_achat_num;

SET TERM !; 
CREATE TRIGGER AINC_demande_achat FOR demande_achat BEFORE INSERT  
AS
BEGIN 
  IF (NEW.demande_achat_numero IS NULL) THEN 
    NEW.demande_achat_numero = GEN_ID(demande_achat_demande_achat_num, 1); 
END! 
SET TERM ;! 

CREATE TABLE demande_achat_lignes(
  demande_achat_ligne_id INTEGER    ,
  demande_achat_ligne_demande_ach INTEGER  NOT NULL  ,
  demande_achat_ligne_ligne INTEGER    ,
  demande_achat_ligne_produit INTEGER  NOT NULL  ,
  demande_achat_ligne_description VARCHAR(255)  NOT NULL  ,
  demande_achat_ligne_delai DATE  NOT NULL  ,
  demande_achat_ligne_qt_cmd DECIMAL(18,2)  NOT NULL  ,
  demande_achat_ligne_pu DECIMAL(18,5)  NOT NULL    ,
  PRIMARY KEY(demande_achat_ligne_id));


CREATE GENERATOR demande_achat_lignes_demande_ac;

SET TERM !; 
CREATE TRIGGER AINC_demande_achat_lignes FOR demande_achat_lignes BEFORE INSERT  
AS
BEGIN 
  IF (NEW.demande_achat_ligne_id IS NULL) THEN 
    NEW.demande_achat_ligne_id = GEN_ID(demande_achat_lignes_demande_ac, 1); 
END! 
SET TERM ;! 

CREATE TABLE historique(
  histor_id INTEGER    ,
  histor_date_mvt DATE  NOT NULL  ,
  histor_produit INTEGER  NOT NULL  ,
  histor_libelle VARCHAR(20)  NOT NULL  ,
  histor_class_mvt VARCHAR(1)    ,
  histor_document INTEGER  NOT NULL  ,
  histor_qt_mvt DECIMAL(18,2)  NOT NULL  ,
  histor_pu_mouvement DECIMAL(18,5)  NOT NULL  ,
  histor_user INTEGER  NOT NULL    ,
  PRIMARY KEY(histor_id));


CREATE GENERATOR historique_histor_id;

SET TERM !; 
CREATE TRIGGER AINC_historique FOR historique BEFORE INSERT  
AS
BEGIN 
  IF (NEW.histor_id IS NULL) THEN 
    NEW.histor_id = GEN_ID(historique_histor_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE ligne_bon_livraison(
  ligne_bl_id INTEGER    ,
  ligne_bl_date DATE  NOT NULL  ,
  ligne_bl_bl INTEGER  NOT NULL  ,
  ligne_bl_realation_ligne_cmd INTEGER  NOT NULL  ,
  ligne_bl_produit INTEGER  NOT NULL  ,
  ligne_bl_description VARCHAR(255)  NOT NULL  ,
  ligne_bl_prix DECIMAL(18,5)  NOT NULL  ,
  ligne_bl_qt DECIMAL(18,5)  NOT NULL    ,
  PRIMARY KEY(ligne_bl_id));


CREATE GENERATOR ligne_bon_livraison_ligne_bl_id;

SET TERM !; 
CREATE TRIGGER AINC_ligne_bon_livraison FOR ligne_bon_livraison BEFORE INSERT  
AS
BEGIN 
  IF (NEW.ligne_bl_id IS NULL) THEN 
    NEW.ligne_bl_id = GEN_ID(ligne_bon_livraison_ligne_bl_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE users(
  user_id INTEGER    ,
  user_nom VARCHAR(30)  NOT NULL  ,
  user_prenom VARCHAR(30)  NOT NULL  ,
  user_profil INTEGER  NOT NULL  ,
  user_fonction VARCHAR(50)  NOT NULL  ,
  user_mail VARCHAR(50)  NOT NULL  ,
  user_login VARCHAR(10)    ,
  user_pass VARCHAR(10)  NOT NULL    ,
  PRIMARY KEY(user_id));


CREATE GENERATOR users_user_login;

SET TERM !; 
CREATE TRIGGER AINC_users FOR users BEFORE INSERT  
AS
BEGIN 
  IF (NEW.user_login IS NULL) THEN 
    NEW.user_login = GEN_ID(users_user_login, 1); 
END! 
SET TERM ;! 

CREATE TABLE profils(
  profil_id INTEGER    ,
  profil_nom VARCHAR(30)  NOT NULL  ,
  profil_description VARCHAR(255)  NOT NULL    ,
  PRIMARY KEY(profil_id));


CREATE GENERATOR profils_profil_id;

SET TERM !; 
CREATE TRIGGER AINC_profils FOR profils BEFORE INSERT  
AS
BEGIN 
  IF (NEW.profil_id IS NULL) THEN 
    NEW.profil_id = GEN_ID(profils_profil_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE ligne_facture(
  ligne_facture_id INTEGER    ,
  ligne_facture_facture INTEGER  NOT NULL  ,
  ligne_facture_ligne INTEGER  NOT NULL  ,
  ligne_facture_affaire INTEGER  NOT NULL  ,
  ligne_facture_ligne_b INTEGER  NOT NULL  ,
  ligne_facture_produit INTEGER  NOT NULL  ,
  ligne_facture_description VARCHAR(255)  NOT NULL  ,
  ligne_facture_qt DECIMAL(18,5)  NOT NULL  ,
  ligne_facture_pu DECIMAL(18,5)  NOT NULL  ,
  ligne_facture_ht DECIMAL(18,5)  NOT NULL  ,
  ligne_facture_tva INTEGER  NOT NULL  ,
  ligne_facture_mnt_tva DECIMAL(18,5)  NOT NULL  ,
  ligne_facture_ttc DECIMAL(18,5)  NOT NULL    ,
  PRIMARY KEY(ligne_facture_id));


CREATE GENERATOR ligne_facture_ligne_facture_id;

SET TERM !; 
CREATE TRIGGER AINC_ligne_facture FOR ligne_facture BEFORE INSERT  
AS
BEGIN 
  IF (NEW.ligne_facture_id IS NULL) THEN 
    NEW.ligne_facture_id = GEN_ID(ligne_facture_ligne_facture_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE ligne_bon_reception(
  ligne_br_id INTEGER    ,
  ligne_br_date DATE  NOT NULL  ,
  ligne_br_br INTEGER  NOT NULL  ,
  ligne_br_relation_ligne_cmd INTEGER  NOT NULL  ,
  ligne_br_produit INTEGER  NOT NULL  ,
  ligne_br_description VARCHAR(255)  NOT NULL  ,
  ligne_br_prix DECIMAL(18,5)    ,
  ligne_br_qt DECIMAL(18,5)      ,
  PRIMARY KEY(ligne_br_id));


CREATE GENERATOR ligne_bon_reception_ligne_br_id;

SET TERM !; 
CREATE TRIGGER AINC_ligne_bon_reception FOR ligne_bon_reception BEFORE INSERT  
AS
BEGIN 
  IF (NEW.ligne_br_id IS NULL) THEN 
    NEW.ligne_br_id = GEN_ID(ligne_bon_reception_ligne_br_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE bon_reception(
  bon_reception_id INTEGER    ,
  bon_reception_facturable VARCHAR(1)  NOT NULL  ,
  bon_reception_affaire INTEGER  NOT NULL  ,
  bon_reception_numero INTEGER    ,
  bon_reception_date_creation DATE  NOT NULL  ,
  bon_reception_commande INTEGER  NOT NULL  ,
  bon_reception_fournisseur INTEGER  NOT NULL  ,
  bon_reception_adresse VARCHAR(255)  NOT NULL  ,
  bon_reception_description VARCHAR(255)  NOT NULL  ,
  bon_reception_facture INTEGER  NOT NULL  ,
  bon_reception_tva INTEGER  NOT NULL    ,
  PRIMARY KEY(bon_reception_id));


CREATE GENERATOR bon_reception_bon_reception_num;

SET TERM !; 
CREATE TRIGGER AINC_bon_reception FOR bon_reception BEFORE INSERT  
AS
BEGIN 
  IF (NEW.bon_reception_numero IS NULL) THEN 
    NEW.bon_reception_numero = GEN_ID(bon_reception_bon_reception_num, 1); 
END! 
SET TERM ;! 

CREATE TABLE parametres(
  param_id INTEGER    ,
  param_nom VARCHAR(30)    ,
  param_adresse VARCHAR(255)  NOT NULL  ,
  param_siret VARCHAR(20)  NOT NULL  ,
  param_tvaintra VARCHAR(20)  NOT NULL  ,
  param_devise VARCHAR(10)  NOT NULL  ,
  param_default_tva INTEGER  NOT NULL  ,
  param_num_devis INTEGER  NOT NULL  ,
  param_num_demande_achat INTEGER  NOT NULL  ,
  param_num_cmd_cl INTEGER  NOT NULL  ,
  param_num_cmd_fr INTEGER  NOT NULL  ,
  param_num_bon_livraison INTEGER  NOT NULL  ,
  param_num_bon_reception INTEGER  NOT NULL  ,
  param_num_facture INTEGER  NOT NULL  ,
  param_num_facture_br INTEGER  NOT NULL  ,
  param_num_affaire INTEGER  NOT NULL  ,
  param_backup_auto VARCHAR(1)  NOT NULL  ,
  param_backup_auto_time INTEGER  NOT NULL  ,
  param_serveurfordata VARCHAR(255)  NOT NULL  ,
  param_url_for_consult VARCHAR(255)  NOT NULL  ,
  param_mail_expeditor VARCHAR(50)  NOT NULL  ,
  param_smtp_serveur VARCHAR(50)  NOT NULL  ,
  param_smtp_port INTEGER  NOT NULL  ,
  param_smtp_ssl VARCHAR(1)  NOT NULL  ,
  param_smtpauthentification VARCHAR(1)  NOT NULL  ,
  param_smtpuserlogin VARCHAR(50)  NOT NULL  ,
  param_smtpuserpassword VARCHAR(50)  NOT NULL  ,
  param_passwordforchange VARCHAR(50)    ,
  param_date_creat DATE      ,
  PRIMARY KEY(param_id));


CREATE GENERATOR parametres_param_nom;

SET TERM !; 
CREATE TRIGGER AINC_parametres FOR parametres BEFORE INSERT  
AS
BEGIN 
  IF (NEW.param_nom IS NULL) THEN 
    NEW.param_nom = GEN_ID(parametres_param_nom, 1); 
END! 
SET TERM ;! 

CREATE TABLE historiquemailfile(
  historiquemailfilefileId INTEGER    ,
  historiquemailfilehistoriquemai INTEGER    ,
  historiquemailfilefile VARCHAR(100)  NOT NULL    ,
  PRIMARY KEY(historiquemailfilefileId));


CREATE GENERATOR historiquemailfile_historiquema;

SET TERM !; 
CREATE TRIGGER AINC_historiquemailfile FOR historiquemailfile BEFORE INSERT  
AS
BEGIN 
  IF (NEW.historiquemailfilefileId IS NULL) THEN 
    NEW.historiquemailfilefileId = GEN_ID(historiquemailfile_historiquema, 1); 
END! 
SET TERM ;! 

CREATE TABLE historiquemail(
  historiquemailid INTEGER    ,
  historiquemailstatus VARCHAR(1)  NOT NULL  ,
  historiquemaildate DATE  NOT NULL  ,
  historiquemailfrom VARCHAR(30)  NOT NULL  ,
  historiquemailto VARCHAR(1000)  NOT NULL  ,
  historiquemailtohiddenrecipient VARCHAR(1)  NOT NULL  ,
  historiquemailsubject VARCHAR(30)  NOT NULL  ,
  historiquemailbody VARCHAR(30)  NOT NULL  ,
  historiquemailerror INTEGER  NOT NULL  ,
  historiquemailuser INTEGER  NOT NULL    ,
  PRIMARY KEY(historiquemailid));


CREATE GENERATOR historiquemail_historiquemailid;

SET TERM !; 
CREATE TRIGGER AINC_historiquemail FOR historiquemail BEFORE INSERT  
AS
BEGIN 
  IF (NEW.historiquemailid IS NULL) THEN 
    NEW.historiquemailid = GEN_ID(historiquemail_historiquemailid, 1); 
END! 
SET TERM ;! 

CREATE TABLE errormessages(
  errormessages_id INTEGER    ,
  errormessagesdate DATE  NOT NULL  ,
  errormessages_type VARCHAR(1)  NOT NULL  ,
  errormessages_document INTEGER  NOT NULL  ,
  errormessages_nom VARCHAR(50)  NOT NULL  ,
  errormessages_description VARCHAR(1000)  NOT NULL  ,
  errormessagesuser INTEGER  NOT NULL    ,
  PRIMARY KEY(errormessages_id));


CREATE GENERATOR errormessages_errormessages_id;

SET TERM !; 
CREATE TRIGGER AINC_errormessages FOR errormessages BEFORE INSERT  
AS
BEGIN 
  IF (NEW.errormessages_id IS NULL) THEN 
    NEW.errormessages_id = GEN_ID(errormessages_errormessages_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE fichiers(
  fichiers_id INTEGER    ,
  fichiers_classeinfo VARCHAR(1)  NOT NULL  ,
  fichiers_element INTEGER  NOT NULL  ,
  fichiers_nom VARCHAR(30)  NOT NULL  ,
  fichier_date_creation DATE  NOT NULL  ,
  fichiers_description VARCHAR(255)  NOT NULL  ,
  fichier VARCHAR(255)  NOT NULL    ,
  PRIMARY KEY(fichiers_id));


CREATE GENERATOR fichiers_fichiers_id;

SET TERM !; 
CREATE TRIGGER AINC_fichiers FOR fichiers BEFORE INSERT  
AS
BEGIN 
  IF (NEW.fichiers_id IS NULL) THEN 
    NEW.fichiers_id = GEN_ID(fichiers_fichiers_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE droits(
  droit_id INTEGER    ,
  droit_description VARCHAR(255)  NOT NULL  ,
  droit_type VARCHAR(1)  NOT NULL  ,
  droit_modele VARCHAR(1)  NOT NULL  ,
  droit_class VARCHAR(30)  NOT NULL  ,
  droit_action VARCHAR(30)  NOT NULL    ,
  PRIMARY KEY(droit_id));


CREATE GENERATOR droits_droit_id;

SET TERM !; 
CREATE TRIGGER AINC_droits FOR droits BEFORE INSERT  
AS
BEGIN 
  IF (NEW.droit_id IS NULL) THEN 
    NEW.droit_id = GEN_ID(droits_droit_id, 1); 
END! 
SET TERM ;! 

CREATE TABLE joint_profils_droits(
  joint_profil INTEGER    ,
  joint_droit INTEGER    ,
  joint_description VARCHAR(255)  NOT NULL    ,
  PRIMARY KEY(joint_profil, joint_droit));


CREATE GENERATOR joint_profils_droits_joint_droi;

SET TERM !; 
CREATE TRIGGER AINC_joint_profils_droits FOR joint_profils_droits BEFORE INSERT  
AS
BEGIN 
  IF (NEW.joint_droit IS NULL) THEN 
    NEW.joint_droit = GEN_ID(joint_profils_droits_joint_droi, 1); 
END! 
SET TERM ;! 

COMMIT;

